@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 $VERSION = eval $VERSION; ## no critic
 
 use Archive::Extract;
@@ -13,7 +13,7 @@ use Cwd;
 use File::Basename qw/ dirname basename /;
 use File::Find;
 use File::Spec;
-use File::Temp qw/ tempdir /;
+use File::Temp;
 use Path::Class;
 use Scalar::Util qw/ reftype /;
 use CPAN::Mini::Visit::Simple::Auxiliary qw(
@@ -75,7 +75,7 @@ sub identify_distros {
         $self->{start_dir} = $args->{start_dir};
     }
     else {
-        $self->{start_dir} = $self->{minicpan};
+        $self->{start_dir} = $self->{id_dir};
     }
 
     if ( defined $args->{pattern} ) {
@@ -95,7 +95,7 @@ sub identify_distros_from_derived_list {
     croak "Bad argument 'pattern' provided to identify_distros_from_derived_list()"
         if exists $args->{pattern};
     croak "identify_distros_from_derived_list() needs 'list' element"
-        unless exists $args->{list}; 
+        unless exists $args->{list};
     croak "Value of 'list' must be array reference"
         unless reftype($args->{list}) eq 'ARRAY';
     croak "Value of 'list' must be non-empty"
@@ -193,7 +193,7 @@ sub refresh_list {
 sub visit {
     my ($self, $args) = @_;
     no warnings 'once';
-    local $Archive::Extract::PREFER_BIN = 1;
+    local $Archive::Extract::PREFER_BIN = 0;
     use warnings 'once';
     local $Archive::Extract::WARN = $args->{quiet} ? 0 : 1;
     croak "Must have a list of distributions on which to take action"
@@ -217,7 +217,7 @@ sub visit {
         @action_args = @{ $args->{action_args} };
     }
     my $here = cwd();
-    foreach my $distro ( @{$self->{list}} ) {
+    LIST: foreach my $distro ( @{$self->{list}} ) {
         my $proper_distro = q{};
         my $real_id_dir = $self->get_id_dir();
         if ( $distro =~ m|$real_id_dir/(.*)| ) {
@@ -229,11 +229,18 @@ sub visit {
             open $olderr, ">&STDERR";
             open STDERR, ">", File::Spec->devnull;
         }
-        my $tdir = tempdir( CLEANUP => 1 );
+        my $tdir = File::Temp->newdir();
         chdir $tdir or croak "Unable to change to temporary directory";
         my $ae = Archive::Extract->new( archive => $distro );
-        my $extract_ok;
-        eval { $extract_ok = $ae->extract( to => $tdir ); };
+        my $extract_ok = $ae->extract( to => $tdir ) or do {
+            warn "Unable to extract $distro; skipping";
+            if ( not $Archive::Extract::WARN ) {
+                open STDERR, ">&", $olderr;
+                close $olderr;
+            }
+            next LIST;
+        };
+
         # restore stderr if quiet
         if ( not $Archive::Extract::WARN ) {
             open STDERR, ">&", $olderr;
